mk2.js (@fengmk2) header
mk2.js (@fengmk2) profile picture

Coding for love.

Hangzhou, China
Joined February 2009
Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)Photo by mk2.js (@fengmk2)
mk2.js retweeted
/ Vue Fes Japan 2026 ありがとうございました! \ ご来場の皆さま、スピーカー・スポンサーの皆さま、本当にありがとうございました🙏 #vuefes のポストは2,800件を超え、トレンド入りもしました🎉 登壇資料はタイムテーブルに掲載中です👇 vuefes.jp/2026/timetable #vuefes
37
3
121
9,026
2 weeks of Void. We did two releases a week so far and are starting to build a team of core contributors. Try it out if you haven’t yet!
We open sourced Void v1.1.11 and we made a music video for it. void.cloud
3
7
49
5,458
Thanks for having me @githubuniverse 🙏🏻 Feeling blessed to get the chance to talk about amazing open source projects like @vite_js plus, chatting with passionate devs, fellow maintainers, and engineers working on projects like @npmjs 🔥
1
3
64
2,186
Node.js 27 Alpha is out! 💚 First release of the new model: Alpha until April, Current on 2027-04 and LTS on 2027-10. What's new: * V8 15.6 🚀 * OpenSSL 4.1, npm 12.1 * --allow-env permission 🔍 * Native fs.glob, net/promises ⚡ * domain deprecated nodejs.org/en/blog/release/v…
7
32
5
246
39,497
Rolldown v1.2.16 is out 🎉 - Speed up builds with thousands of dynamic imports - Cheaper `chunk.code` / `renderedLength` reads in plugins - Support `experimentalInlineCommonChunks` in Vite's bundled dev mode - More bug fixes and improvements
1
9
2
93
5,277
The Up and to the Right Company of Singapore and Japan
2
1
20
1,927
In the next version of Rolldown The cycle check in chunk merging is now incremental: it builds the chunk graph once, not once per merge O(merges × graph) → O(graph + merges × reach) Apps with thousands of dynamic imports build up to 37× faster
2
8
48
4,201
My colleague found a massive perf speedup for Oxlint JS plugins. V8 changed how object prototypes are initialized - `{ __proto__: X }` was a fast path last year, but no longer. Our mistake was not to notice perf had regressed on recent NodeJS versions. Shame on me, and props to @wan9chi!
3
11
139
6,546
More new contributors joining Rolldown! Thanks for all your contributions and support — PRs, issues, and everything in between! ❤️
2
1
44
4,258
42s → 8s → 5s Type-checking one of our Vue codebases (~1k files, ~200 SFCs): vue-tsc + TS6 → TS 7.1 → tsrs --fast TS 7.1 and tsrs run Vue through the new @vue/content-mapper alpha. I'm excited.
4
8
175
9,778
mk2.js retweeted
For Vinext 1.4, we spent a lot of time optimising parts of our rendering pipeline and cutting out unnecessary work, which led to some nice speed-ups on a Hacker News benchmark. vinext.dev/blog/vinext-1-4
2
6
31
2,353
mk2.js retweeted
i just started working on incremental and persistent cache for Rolldown. stay tuned guys
1
2
40
1,195
In the next version of Rolldown Plugins reading `chunk.code` or `renderedLength` no longer copy the chunk code from Rust to JS on every read The bigger the bundle and the more plugins read `chunk.code`, the more you save
1
9
35
2,284
mk2.js retweeted
I migrated the Cloudflare Certification monorepo to @voidzerodev's Vite+. Some stats: - Production builds: −59% (admin), −41% (user): that's Vite 8 / Rolldown, zero code changes - Type-check the whole monorepo: 21 s (6× tsc) to 5.3 s (tsgo, one command) Moreover, this migration helped find: - 940 type errors nothing had ever caught - a WebSocket close-code bug in a Durable Object - a render loop only the e2e suite could see. Still need to do some work for the complete migration, but this looks promising. The goal is to move to modern tooling, without (hopefully!) breaking anything.
6
4
1
58
4,847